summaryrefslogtreecommitdiffstats
path: root/generic/tclEvent.c
diff options
context:
space:
mode:
Diffstat (limited to 'generic/tclEvent.c')
-rw-r--r--generic/tclEvent.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/generic/tclEvent.c b/generic/tclEvent.c
index 3449db1..0466db3 100644
--- a/generic/tclEvent.c
+++ b/generic/tclEvent.c
@@ -11,7 +11,7 @@
* See the file "license.terms" for information on usage and redistribution
* of this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tclEvent.c,v 1.30 2003/09/29 21:38:49 dkf Exp $
+ * RCS: @(#) $Id: tclEvent.c,v 1.31 2003/12/24 04:18:19 davygrvy Exp $
*/
#include "tclInt.h"
@@ -617,7 +617,7 @@ Tcl_Exit(status)
/*
* Warning: this code SHOULD NOT return, as there is code that
* depends on Tcl_Exit never returning. In fact, we will
* panic if anyone returns, so critical is this dependcy.
*/
currentAppExitPtr((ClientData) status);
Tcl_Panic("AppExitProc returned unexpectedly");
@@ -742,7 +742,7 @@ TclInitSubsystems(argv0)
ThreadSpecificData *tsdPtr;
if (inFinalize != 0) {
- panic("TclInitSubsystems called while finalizing");
+ Tcl_Panic("TclInitSubsystems called while finalizing");
}
/*
@@ -1180,7 +1180,7 @@ Tcl_UpdateObjCmd(clientData, interp, objc, objv)
break;
}
default: {
- panic("Tcl_UpdateObjCmd: bad option index to UpdateOptions");
+ Tcl_Panic("Tcl_UpdateObjCmd: bad option index to UpdateOptions");
}
}
} else {
@@ -617,7 +617,7 @@ Tcl_Exit(status)
* Warning: this code SHOULD NOT return, as there is code that
* depends on Tcl_Exit never returning. In fact, we will
- * panic if anyone returns, so critical is this dependcy.
+ * Tcl_Panic if anyone returns, so critical is this dependcy.
*/
currentAppExitPtr((ClientData) status);